==> nocc-1.8.1.tbz: www/nocc/lang/ia.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ia.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Interlingua (Interlingua)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author McDutchie
 */

$lang_locale = 'ia.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Nulle nomine de usator entrate';
$err_passwd_empty = 'Nulle contrasigno entrate';
$alt_delete = 'Deler le messages seligite';
$alt_delete_one = 'Deler le messsage';
$alt_new_msg = 'Nove messages';
$alt_reply = 'Responder al autor';
$alt_reply_all = 'Responder a totes';
$alt_forward = 'Reexpedir';
$alt_next = 'Sequente';
$alt_prev = 'Precedente';
$title_next_page = 'Pagina sequente';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Message sequente';
$title_prev_msg = 'Message precedente';
$html_on = 'active';
$html_theme_label = 'Thema:';
$html_welcome = 'Benvenite a %1$s';
$html_login = 'Usator';
$html_passwd = 'Contrasigno';
$html_submit = 'Entrar';
$html_help = 'Adjuta';
$html_server = 'Servitor';
$html_wrong = 'Le nomine de usator o le contrasigno es incorrecte';
$html_retry = 'Reprovar';
$html_remember = 'Memorar parametros';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Messages per pagina:';
$html_preferences = 'Preferentias';
$html_full_name_label = 'Nomine complete:';
$html_email_address_label = 'Adresse de e-mail:';
$html_ccself = 'Copia proprie';
$html_hide_addresses = 'Celar adresses';
$html_outlook_quoting = 'Citation in stilo de Outlook';
$html_reply_to = 'Responder a';
$html_use_signature = 'Usar signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura:';
$html_reply_leadin_label = 'Prefixo pro responsas:';
$html_prefs_updated = 'Preferentias actualisate';
$html_manage_folders_link = 'Gerer le dossiers IMAP';
$html_manage_filters_link = 'Gerer le filtros de e-mail';
$html_use_graphical_smilies = 'Usar emoticones graphic';
$html_sent_folder_label = 'Copiar le messages inviate in un dossier dedicate:';
$html_trash_folder_label = 'Mover le messages delite in un dossier dedicate:';
$html_colored_quotes = 'Citationes con colores';
$html_display_struct = 'Monstrar texto structurate';
$html_send_html_mail = 'Inviar e-mail in formato HTML';
$html_folders = 'Dossieres';
$html_folders_create_failed = 'Le dossier non poteva esser create!';
$html_folders_sub_failed = 'Non poteva subscriber al dossier!';
$html_folders_unsub_failed = 'Non poteva cancellar le subscription al dossier!';
$html_folders_rename_failed = 'Le dossier non poteva esser renominate!';
$html_folders_updated = 'Dossieres actualisate';
$html_folder_subscribe = 'Subscriber a';
$html_folder_rename = 'Renominar';
$html_folder_create = 'Crear un nove dossier con nomine';
$html_folder_remove = 'Cancellar subscription a';
$html_folder_delete = 'Deler';
$html_folder_to = 'a';
$html_filter_remove = 'Deler';
$html_filter_body = 'Corpore del message';
$html_filter_subject = 'Subjecto del message';
$html_filter_to = 'Campo "a"';
$html_filter_cc = 'Campo "Cc"';
$html_filter_from = 'Campo "De"';
$html_filter_change_tip = 'Pro cambiar un filtro simplemente superscribe lo.';
$html_reapply_filters = 'Reapplicar tote le filtros';
$html_filter_contains = 'contine';
$html_filter_name = 'Nomine del filtro';
$html_filter_action = 'Action pro filtro';
$html_filter_moveto = 'Mover a';
$html_select_one = '--Selige un--';
$html_and = 'e';
$html_new_msg_in = 'Nove messages in';
$html_or = 'o';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'le messages seligite a';
$html_gotopage = 'Ir al pagina';
$html_gotofolder = 'Ir al dossier';
$html_other_folders = 'Lista de dossieres';
$html_page = 'Pagina';
$html_of = 'de';
$html_view_header = 'Vider capite';
$html_remove_header = 'Celar capite';
$html_inbox = 'Messages recipite';
$html_new_msg = 'Scriber';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a totes';
$html_forward = 'Reinviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Le message reinviate essera inviate como annexo a iste.';
$html_delete = 'Deler';
$html_new = 'Nove';
$html_mark = 'Deler';
$html_att_label = 'Annexo:';
$html_atts_label = 'Annexos';
$html_att_unknown = '[incognite]';
$html_attach = 'Annexar';
$html_attach_forget = 'Es necessari annexar le file ante de inviar le message!';
$html_attach_delete = 'Remover le files seligite';
$html_attach_none = 'Tu debe seliger un file a annexar!';
$html_sort_by = 'Ordinar per';
$html_sort = 'Ordinar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Subjecto';
$html_subject_label = 'Subjecto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent = 'Inviate:';
$html_wrote = 'scribeva';
$html_size = 'Dimension';
$html_totalsize = 'Dimension total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nomine de file';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cco:';
$html_nosubject = 'Sin subjecto';
$html_send = 'Inviar';
$html_cancel = 'Cancellar';
$html_no_mail = 'Nulle message.';
$html_logout = 'Clauder session';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Iste servitor non es ben configurate!';
$html_priority = 'Prioritate';
$html_priority_label = 'Prioritate:';
$html_lowest = 'Minimal';
$html_low = 'Basse';
$html_normal = 'Normal';
$html_high = 'Alte';
$html_highest = 'Maximal';
$html_receipt = 'Requestar confirmation de reception';
$html_select = 'Seliger';
$html_select_all = 'Inverter selection';
$html_loading_image = 'Carga imagine';
$html_send_confirmed = 'Tu message ha essite acceptate pro livration';
$html_no_sendaction = 'Nulle action specificate. Prova activar JavaScript.';
$html_error_occurred = 'Un error ha occurrite';
$html_prefs_file_error = 'Impossibile aperir le file de preferentias pro scriber.';
$html_wrap = 'Numero de characteres in le qual divider le lineas del messages sortiente:';
$html_wrap_none = 'Non divider le lineas';
$html_usenet_separator = 'Separator Usenet ("-- \n") ante signatura';
$html_mark_as = 'Marcar como';
$html_read = 'legite';
$html_unread = 'non legite';
$html_encoding_label = 'Codification de characteres:';
$html_add = 'Adder';
$html_contacts = 'Contactos de %1$s';
$html_modify = 'Modificar';
$html_back = 'Retornar';
$html_contact_add = 'Adder un nove contacto';
$html_contact_mod = 'Modificar un contacto';
$html_contact_first = 'Prenomine';
$html_contact_last = 'Nomine de familia';
$html_contact_nick = 'Pseudonymo';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'ab le lista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'Le numero maxime de contactos es "%1$d"';
$html_contact_err2 = 'Tu non pote adder un nove contacto';
$html_contact_err3 = 'Tu non ha le permission de acceder al lista de contactos';
$html_contact_none = 'Nulle contacto poteva esser trovate.';
$html_del_msg = 'Deler le messages seligite?';
$html_down_mail = 'Discargar';
$original_msg = '-- Message original --';
$to_empty = 'Le campo \'A\' non debe esser vacue!';
$html_images_warning = 'Pro motivos de securitate, le imagines remote non es monstrate.';
$html_images_display = 'Monstrar imagines';
$html_smtp_error_no_conn = 'Impossibile aperir connexion SMTP';
$html_smtp_error_unexpected = 'Responsa SMTP non expectate:';
$lang_could_not_connect = 'Non pote connecter al servitor';
$lang_invalid_msg_num = 'Mal numero de message';
$html_file_upload_attack = 'Possibile attacco implicante le cargamento de files';
$html_invalid_email_address = 'Adresse de e-mail invalide';
$html_invalid_msg_per_page = 'Numero invalide de messages per pagina';
$html_invalid_wrap_msg = 'Limite de division invalide pro le lineas de messages';
$html_seperate_msg_win = 'Messages in fenestra separate';
$html_err_file_contacts = 'Impossibile aperir le file de contactos pro scriber.';
$html_session_file_error = 'Impossibile aperir le file de session pro scriber.';
$html_login_not_allowed = 'Iste identitate non es permittite pro connexion.';
$lang_err_send_delay = 'Tu debe attender inter duo messages (%1$d secundas)';
$html_search = 'Cercar';

==> nocc-1.8.3.tbz: www/nocc/lang/ia.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ia.php 2188 2010-05-16 15:57:32Z siebrand $
 */

/** Interlingua (Interlingua)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author McDutchie
 */

$lang_locale = 'ia.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Nulle nomine de usator entrate';
$err_passwd_empty = 'Nulle contrasigno entrate';
$alt_delete = 'Deler le messages seligite';
$alt_delete_one = 'Deler le messsage';
$alt_new_msg = 'Nove messages';
$alt_reply = 'Responder al autor';
$alt_reply_all = 'Responder a totes';
$alt_forward = 'Reinviar';
$alt_next = 'Sequente';
$alt_prev = 'Precedente';
$title_next_page = 'Pagina sequente';
$title_prev_page = 'Pagina precedente';
$title_next_msg = 'Message sequente';
$title_prev_msg = 'Message precedente';
$html_theme_label = 'Thema:';
$html_welcome = 'Benvenite a %1$s';
$html_login = 'Aperir session';
$html_user_label = 'Usator:';
$html_passwd_label = 'Contrasigno:';
$html_submit = 'Entrar';
$html_help = 'Adjuta';
$html_server_label = 'Servitor:';
$html_wrong = 'Le nomine de usator o le contrasigno es incorrecte';
$html_retry = 'Reprobar';
$html_remember = 'Memorar optiones';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Messages per pagina:';
$html_preferences = 'Preferentias';
$html_full_name_label = 'Nomine complete:';
$html_email_address_label = 'Adresse de e-mail:';
$html_ccself = 'Copia proprie';
$html_hide_addresses = 'Celar adresses';
$html_outlook_quoting = 'Citation in stilo de Outlook';
$html_reply_to = 'Responder a';
$html_use_signature = 'Usar signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura:';
$html_reply_leadin_label = 'Prefixo pro responsas:';
$html_prefs_updated = 'Preferentias actualisate';
$html_manage_folders_link = 'Gerer le dossiers IMAP';
$html_manage_filters_link = 'Gerer le filtros de e-mail';
$html_use_graphical_smilies = 'Usar emoticones graphic';
$html_sent_folder_label = 'Copiar le messages inviate in un dossier dedicate:';
$html_trash_folder_label = 'Displaciar le messages delite in un dossier dedicate:';
$html_colored_quotes = 'Citationes con colores';
$html_display_struct = 'Monstrar texto structurate';
$html_send_html_mail = 'Inviar e-mail in formato HTML';
$html_folders = 'Dossieres';
$html_folders_create_failed = 'Le dossier non poteva esser create!';
$html_folders_sub_failed = 'Non poteva subscriber al dossier!';
$html_folders_unsub_failed = 'Non poteva cancellar le subscription al dossier!';
$html_folders_rename_failed = 'Le dossier non poteva esser renominate!';
$html_folders_updated = 'Dossieres actualisate';
$html_folder_subscribe = 'Subscriber a';
$html_folder_rename = 'Renominar';
$html_folder_create = 'Crear un nove dossier con nomine';
$html_folder_remove = 'Cancellar subscription a';
$html_folder_delete = 'Deler';
$html_folder_to = 'a';
$html_filter_remove = 'Deler';
$html_filter_body = 'Corpore del message';
$html_filter_subject = 'Subjecto del message';
$html_filter_to = 'Campo "a"';
$html_filter_cc = 'Campo "Cc"';
$html_filter_from = 'Campo "De"';
$html_filter_change_tip = 'Pro cambiar un filtro simplemente superscribe lo.';
$html_reapply_filters = 'Reapplicar tote le filtros';
$html_filter_contains = 'contine';
$html_filter_name = 'Nomine del filtro';
$html_filter_action = 'Action pro filtro';
$html_filter_moveto = 'Displaciar a';
$html_select_one = '--Selige un--';
$html_and = 'e';
$html_new_msg_in = 'Nove messages in';
$html_or = 'o';
$html_move = 'Displaciar';
$html_copy = 'Copiar';
$html_messages_to = 'le messages seligite a';
$html_gotopage = 'Ir al pagina';
$html_gotofolder = 'Ir al dossier';
$html_other_folders = 'Lista de dossieres';
$html_page = 'Pagina';
$html_of = 'de';
$html_view_header = 'Vider capite';
$html_remove_header = 'Celar capite';
$html_inbox = 'Messages recipite';
$html_new_msg = 'Scriber';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a totes';
$html_forward = 'Reinviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Le message reinviate essera inviate como annexo a iste.';
$html_delete = 'Deler';
$html_new = 'Nove';
$html_mark = 'Deler';
$html_att_label = 'Annexo:';
$html_atts_label = 'Annexos:';
$html_unknown = '[incognite]';
$html_attach = 'Annexar';
$html_attach_forget = 'Es necessari annexar le file ante de inviar le message!';
$html_attach_delete = 'Remover le files seligite';
$html_attach_none = 'Tu debe seliger un file a annexar!';
$html_sort_by = 'Ordinar per';
$html_sort = 'Ordinar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Subjecto';
$html_subject_label = 'Subjecto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Inviate:';
$html_wrote = 'scribeva';
$html_size = 'Dimension';
$html_totalsize = 'Dimension total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nomine de file';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cco:';
$html_nosubject = 'Sin subjecto';
$html_send = 'Inviar';
$html_cancel = 'Cancellar';
$html_no_mail = 'Nulle message.';
$html_logout = 'Clauder session';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Iste servitor non es ben configurate!';
$html_priority = 'Prioritate';
$html_priority_label = 'Prioritate:';
$html_lowest = 'Minimal';
$html_low = 'Basse';
$html_normal = 'Normal';
$html_high = 'Alte';
$html_highest = 'Maximal';
$html_flagged = 'Marcate';
$html_spam = 'Spam';
$html_spam_warning = 'Iste message ha essite classificate como spam.';
$html_receipt = 'Requestar confirmation de reception';
$html_select = 'Seliger';
$html_select_all = 'Inverter selection';
$html_select_contacts = 'Selige contactos';
$html_loading_image = 'Carga imagine';
$html_send_confirmed = 'Tu message ha essite acceptate pro livration';
$html_no_sendaction = 'Nulle action specificate. Prova activar JavaScript.';
$html_error_occurred = 'Un error ha occurrite';
$html_prefs_file_error = 'Impossibile aperir le file de preferentias pro scriber.';
$html_wrap = 'Numero de characteres in le qual divider le lineas del messages sortiente:';
$html_wrap_none = 'Non divider le lineas';
$html_usenet_separator = 'Separator Usenet ("-- \n") ante signatura';
$html_mark_as = 'Marcar como';
$html_read = 'legite';
$html_unread = 'non legite';
$html_encoding_label = 'Codification de characteres:';
$html_add = 'Adder';
$html_contacts = 'Contactos de %1$s';
$html_modify = 'Modificar';
$html_back = 'Retornar';
$html_contact_add = 'Adder un nove contacto';
$html_contact_mod = 'Modificar un contacto';
$html_contact_first = 'Prenomine';
$html_contact_last = 'Nomine de familia';
$html_contact_nick = 'Pseudonymo';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'ab le lista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'Le numero maxime de contactos es "%1$d"';
$html_contact_err2 = 'Tu non pote adder un nove contacto';
$html_contact_err3 = 'Tu non ha le permission de acceder al lista de contactos';
$html_contact_none = 'Nulle contacto poteva esser trovate.';
$html_del_msg = 'Deler le messages seligite?';
$html_down_mail = 'Discargar';
$original_msg = '-- Message original --';
$to_empty = 'Le campo \'A\' non debe esser vacue!';
$html_images_warning = 'Pro motivos de securitate, le imagines remote non es monstrate.';
$html_images_display = 'Monstrar imagines';
$html_smtp_error_no_conn = 'Impossibile aperir connexion SMTP';
$html_smtp_error_unexpected = 'Responsa SMTP non expectate:';
$lang_could_not_connect = 'Non pote connecter al servitor';
$lang_invalid_msg_num = 'Mal numero de message';
$html_file_upload_attack = 'Possibile attacco implicante le incargamento de files';
$html_invalid_email_address = 'Adresse de e-mail invalide';
$html_invalid_msg_per_page = 'Numero invalide de messages per pagina';
$html_invalid_wrap_msg = 'Limite de division invalide pro le lineas de messages';
$html_seperate_msg_win = 'Messages in fenestra separate';
$html_err_file_contacts = 'Impossibile aperir le file de contactos pro scriber.';
$html_session_file_error = 'Impossibile aperir le file de session pro scriber.';
$html_login_not_allowed = 'Iste nomine de ustor non es permittite pro connexion.';
$lang_err_send_delay = 'Tu debe attender inter duo messages (%1$d secundas)';
$html_search = 'Cercar';
